pub struct SvsLevelData {
pub level: PyramidLevel,
pub tile_data: TileData,
}Expand description
Data for a single pyramid level in an SVS file.
This includes the level metadata plus cached tile location data and JPEGTables for merging with abbreviated tile streams.
Fields
level: PyramidLevelThe pyramid level metadata
tile_data: TileDataTile offsets and byte counts
Implementations
Sourceimpl SvsLevelData
impl SvsLevelData