pub struct ValueReader<'a, R: RangeReader> { /* private fields */ }Expand description
Reads tag values from a TIFF file.
This struct combines a RangeReader with TIFF header information to read values respecting the file’s byte order and format.
Implementations
Sourceimpl<'a, R: RangeReader> ValueReader<'a, R>
impl<'a, R: RangeReader> ValueReader<'a, R>
Sourcepub fn new(reader: &'a R, header: &'a TiffHeader) -> Self
pub fn new(reader: &'a R, header: &'a TiffHeader) -> Self
Create a new ValueReader.
Sourcepub fn byte_order(&self) -> ByteOrder
pub fn byte_order(&self) -> ByteOrder
Get the byte order from the header.
Sourcepub async fn read_bytes(&self, entry: &IfdEntry) -> Result<Bytes, TiffError>
pub async fn read_bytes(&self, entry: &IfdEntry) -> Result<Bytes, TiffError>
Read raw bytes for an IFD entry’s value.
For inline values, returns the bytes from the entry. For offset values, fetches the bytes from the file.
Sourcepub async fn read_u32(&self, entry: &IfdEntry) -> Result<u32, TiffError>
pub async fn read_u32(&self, entry: &IfdEntry) -> Result<u32, TiffError>
Read a single u32 value from an entry.
Handles both Short and Long field types, converting as needed.
Sourcepub async fn read_u64(&self, entry: &IfdEntry) -> Result<u64, TiffError>
pub async fn read_u64(&self, entry: &IfdEntry) -> Result<u64, TiffError>
Read a single u64 value from an entry.
Handles Short, Long, and Long8 field types, converting as needed.
Sourcepub async fn read_u64_array(
&self,
entry: &IfdEntry,
) -> Result<Vec<u64>, TiffError>
pub async fn read_u64_array( &self, entry: &IfdEntry, ) -> Result<Vec<u64>, TiffError>
Read an array of u64 values from an entry.
This is the primary method for reading TileOffsets and TileByteCounts. The entire array is fetched in a single range request for efficiency.
Handles Short, Long, and Long8 field types, converting all to u64.
Sourcepub async fn read_u32_array(
&self,
entry: &IfdEntry,
) -> Result<Vec<u32>, TiffError>
pub async fn read_u32_array( &self, entry: &IfdEntry, ) -> Result<Vec<u32>, TiffError>
Read an array of u32 values from an entry.
Similar to read_u64_array but returns u32 values. Useful for tile dimensions and other 32-bit array values.