pub struct SignedUrlAuth { /* private fields */ }Expand description
Signed URL authenticator using HMAC-SHA256.
This struct provides methods for generating and verifying signed URLs. The signing scheme binds signatures to paths, query params, and expiry times.
Implementations
Sourceimpl SignedUrlAuth
impl SignedUrlAuth
Sourcepub fn new(secret_key: impl AsRef<[u8]>) -> Self
pub fn new(secret_key: impl AsRef<[u8]>) -> Self
Create a new authenticator with the given secret key.
Arguments
secret_key- The secret key used for HMAC computation. Should be at least 32 bytes for security.
Sourcepub fn sign_with_params(
&self,
path: &str,
ttl: Duration,
params: &[(&str, &str)],
) -> (String, u64)
pub fn sign_with_params( &self, path: &str, ttl: Duration, params: &[(&str, &str)], ) -> (String, u64)
Sign a path with extra query parameters.
params should exclude exp and sig; those are added automatically.
Sourcepub fn sign_with_expiry(&self, path: &str, expiry: u64) -> String
pub fn sign_with_expiry(&self, path: &str, expiry: u64) -> String
Sourcepub fn sign_with_expiry_and_params(
&self,
path: &str,
expiry: u64,
params: &[(&str, &str)],
) -> String
pub fn sign_with_expiry_and_params( &self, path: &str, expiry: u64, params: &[(&str, &str)], ) -> String
Sign a path with a specific expiry timestamp and extra parameters.
params should exclude exp and sig; those are added automatically.
Sourcepub fn verify(
&self,
path: &str,
signature: &str,
expiry: u64,
params: &[(&str, &str)],
) -> Result<(), AuthError>
pub fn verify( &self, path: &str, signature: &str, expiry: u64, params: &[(&str, &str)], ) -> Result<(), AuthError>
Sourcepub fn generate_signed_url(
&self,
base_url: &str,
path: &str,
ttl: Duration,
extra_params: &[(&str, &str)],
) -> String
pub fn generate_signed_url( &self, base_url: &str, path: &str, ttl: Duration, extra_params: &[(&str, &str)], ) -> String
Sourcepub fn generate_viewer_token(
&self,
slide_id: &str,
ttl: Duration,
) -> (String, u64)
pub fn generate_viewer_token( &self, slide_id: &str, ttl: Duration, ) -> (String, u64)
Generate a viewer token for accessing all tiles of a specific slide.
Viewer tokens are special tokens that authorize access to all tiles for a given slide, rather than signing individual tile paths. This is used by the built-in viewer to access tiles when auth is enabled.
Arguments
slide_id- The slide identifierttl- How long the token should be valid
Returns
A tuple of (token, expiry_timestamp)